@@ -11,7 +11,7 @@ use JSON::XS;
 
 use Readonly;
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 =head1 NAME
 
@@ -51,6 +51,7 @@ Readonly my %ROUTES   => (
     pageattachment => $BASE_URI
         . '/:ws/pages/:pname/attachments/:attachment_id',
     pageattachments      => $BASE_URI . '/:ws/pages/:pname/attachments',
+    revisions            => $BASE_URI . '/:ws/pages/:pname/revisions',
     taggedpages          => $BASE_URI . '/:ws/tags/:tag/pages',
     workspace            => $BASE_URI . '/:ws',
     workspaces           => $BASE_URI,
@@ -552,6 +553,14 @@ sub get_pages {
     return $self->_get_things('pages');
 }
 
+=head2 get_page_attachments 
+
+    $Rester->get_page_attachments($page)
+
+List all the attachments on a page.
+
+=cut
+
 sub get_page_attachments {
     my $self = shift;
     my $pname = shift;
@@ -559,6 +568,21 @@ sub get_page_attachments {
     return $self->_get_things( 'pageattachments', pname => $pname );
 }
 
+=head2 get_revisions
+
+    $Rester->get_revisions($page)
+
+List all the revisions of a page.
+
+=cut
+
+sub get_revisions {
+    my $self = shift;
+    my $pname = shift;
+
+    return $self->_get_things( 'revisions', pname => $pname );
+}
+
 sub _extend_uri {
     my $self = shift;
     my $uri = shift;
@@ -780,6 +804,25 @@ sub get_breadcrumbs {
     return $self->_get_things('breadcrumbs');
 }
 
+=head2 get_workspace
+
+    $Rester->get_workspace();
+
+Return the metadata about a particular workspace.
+
+=cut
+
+sub get_workspace {
+    my $self = shift;
+    my $wksp = shift;
+
+    my $prev_wksp = $self->workspace();
+    $self->workspace($wksp) if $wksp;
+    my $result = $self->_get_things('workspace');
+    $self->workspace($prev_wksp) if $wksp;
+    return $result;
+}
+
 =head2 get_workspaces
 
     $Rester->get_workspaces();
@@ -980,6 +1023,10 @@ Kirsten Jones C<< <kirsten.jones@socialtext.com> >>
 Luke Closs C<< <luke.closs@socialtext.com> >>
 Shawn Devlin C<< <shawn.devlin@socialtext.com> >>
 
+=head2 OTHER CONTRIBUTORS
+
+Michele Berg - get_revisions()
+
 =cut
 
 1;
